WK3l15k
=======

.. currentmodule:: pykeen.datasets

.. autoclass:: WK3l15k
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~WK3l15k.DATASET_NAME
      ~WK3l15k.FILE_NAMES

   .. rubric:: Attributes Documentation

   .. autoattribute:: DATASET_NAME
   .. autoattribute:: FILE_NAMES
